@@ -12,18 +12,25 @@ import requests
 from wagtail import VERSION as WAGTAIL_VERSION
 from wagtail.utils.widgets import WidgetWithScript
 
+try:
+    from wagtail.telepath import register
+except ImportError:
+    try:
+        # Wagtail<3.0
+        from wagtail.core.telepath import register
+    except ImportError:  # do-nothing fallback for Wagtail <2.13
+        def register(adapter, cls):
+            pass
 
 try:
-    from wagtail.core.telepath import register
-    from wagtail.core.widget_adapters import WidgetAdapter
-except ImportError:  # do-nothing fallback for Wagtail <2.13
-
-    def register(adapter, cls):
-        pass
-
-    class WidgetAdapter:
-        pass
-
+    from wagtail.widget_adapters import WidgetAdapter
+except ImportError:
+    try:
+        # Wagtail<3.0
+        from wagtail.core.widget_adapters import WidgetAdapter
+    except ImportError:  # do-nothing fallback for Wagtail <2.13
+        class WidgetAdapter:
+            pass
 
 class AdminChooser(WidgetWithScript, widgets.Input):
     input_type = 'hidden'
@@ -168,10 +175,17 @@ class AdminChooser(WidgetWithScript, widgets.Input):
         super().__init__(**kwargs)
 
     class Media:
-        js = [
-            'generic_chooser/js/chooser-modal.js',
-            'generic_chooser/js/chooser-widget.js',
-        ]
+        if WAGTAIL_VERSION >= (3, 0):
+            js = [
+                'generic_chooser/js/tabs.js',
+                'generic_chooser/js/chooser-modal.js',
+                'generic_chooser/js/chooser-widget.js',
+            ]
+        else:
+            js = [
+                'generic_chooser/js/chooser-modal.js',
+                'generic_chooser/js/chooser-widget.js',
+            ]
 
 
 class AdminChooserAdapter(WidgetAdapter):
@@ -237,10 +251,17 @@ class LinkedFieldMixin:
 
     @property
     def media(self):
-        return super().media + Media(js=[
-            'generic_chooser/js/chooser-widget.js',
-            'generic_chooser/js/linked-field-chooser-widget.js',
-        ])
+        if WAGTAIL_VERSION >= (3, 0):
+            return super().media + Media(js=[
+                'generic_chooser/js/tabs.js',
+                'generic_chooser/js/chooser-widget.js',
+                'generic_chooser/js/linked-field-chooser-widget.js',
+            ])
+        else:
+            return super().media + Media(js=[
+                'generic_chooser/js/chooser-widget.js',
+                'generic_chooser/js/linked-field-chooser-widget.js',
+            ])
 
 
 class LinkedFieldChooserAdapter(WidgetAdapter):
